==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPlot.java <==
// java wrapper for vtkPlot object
//

package vtk;
import vtk.*;

public class vtkPlot extends vtkContextItem
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLegendVisibility_2(boolean id0);
  public void SetLegendVisibility(boolean id0)
    { SetLegendVisibility_2(id0); }

  private native boolean GetLegendVisibility_3();
  public boolean GetLegendVisibility()
    { return GetLegendVisibility_3(); }

  private native void LegendVisibilityOn_4();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_4(); }

  private native void LegendVisibilityOff_5();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_5(); }

  private native void SetTooltipLabelFormat_6(String id0);
  public void SetTooltipLabelFormat(String id0)
    { SetTooltipLabelFormat_6(id0); }

  private native String GetTooltipLabelFormat_7();
  public String GetTooltipLabelFormat()
    { return GetTooltipLabelFormat_7(); }

  private native void SetTooltipNotation_8(int id0);
  public void SetTooltipNotation(int id0)
    { SetTooltipNotation_8(id0); }

  private native int GetTooltipNotation_9();
  public int GetTooltipNotation()
    { return GetTooltipNotation_9(); }

  private native void SetTooltipPrecision_10(int id0);
  public void SetTooltipPrecision(int id0)
    { SetTooltipPrecision_10(id0); }

  private native int GetTooltipPrecision_11();
  public int GetTooltipPrecision()
    { return GetTooltipPrecision_11(); }

  private native void SetColor_12(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_12(id0,id1,id2,id3); }

  private native void SetColor_13(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_13(id0,id1,id2); }

  private native void GetColor_14(double id0[]);
  public void GetColor(double id0[])
    { GetColor_14(id0); }

  private native void SetWidth_15(double id0);
  public void SetWidth(double id0)
    { SetWidth_15(id0); }

  private native double GetWidth_16();
  public double GetWidth()
    { return GetWidth_16(); }

  private native void SetPen_17(vtkPen id0);
  public void SetPen(vtkPen id0)
    { SetPen_17(id0); }

  private native long GetPen_18();
  public vtkPen GetPen() {
    long temp = GetPen_18();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetBrush_19(vtkBrush id0);
  public void SetBrush(vtkBrush id0)
    { SetBrush_19(id0); }

  private native long GetBrush_20();
  public vtkBrush GetBrush() {
    long temp = GetBrush_20();

    if (temp == 0) return null;
    return (vtkBrush)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectionPen_21(vtkPen id0);
  public void SetSelectionPen(vtkPen id0)
    { SetSelectionPen_21(id0); }

  private native long GetSelectionPen_22();
  public vtkPen GetSelectionPen() {
    long temp = GetSelectionPen_22();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectionBrush_23(vtkBrush id0);
  public void SetSelectionBrush(vtkBrush id0)
    { SetSelectionBrush_23(id0); }

  private native long GetSelectionBrush_24();
  public vtkBrush GetSelectionBrush() {
    long temp = GetSelectionBrush_24();

    if (temp == 0) return null;
    return (vtkBrush)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLabel_25(String id0);
  public void SetLabel(String id0)
    { SetLabel_25(id0); }

  private native String GetLabel_26();
  public String GetLabel()
    { return GetLabel_26(); }

  private native void SetLabels_27(vtkStringArray id0);
  public void SetLabels(vtkStringArray id0)
    { SetLabels_27(id0); }

  private native long GetLabels_28();
  public vtkStringArray GetLabels() {
    long temp = GetLabels_28();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfLabels_29();
  public int GetNumberOfLabels()
    { return GetNumberOfLabels_29(); }

  private native String GetLabel_30(int id0);
  public String GetLabel(int id0)
    { return GetLabel_30(id0); }

  private native void SetIndexedLabels_31(vtkStringArray id0);
  public void SetIndexedLabels(vtkStringArray id0)
    { SetIndexedLabels_31(id0); }

  private native long GetIndexedLabels_32();
  public vtkStringArray GetIndexedLabels() {
    long temp = GetIndexedLabels_32();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetData_33();
  public vtkContextMapper2D GetData() {
    long temp = GetData_33();

    if (temp == 0) return null;
    return (vtkContextMapper2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native boolean GetUseIndexForXSeries_34();
  public boolean GetUseIndexForXSeries()
    { return GetUseIndexForXSeries_34(); }

  private native void SetUseIndexForXSeries_35(boolean id0);
  public void SetUseIndexForXSeries(boolean id0)
    { SetUseIndexForXSeries_35(id0); }

  private native void SetInputData_36(vtkTable id0);
  public void SetInputData(vtkTable id0)
    { SetInputData_36(id0); }

  private native void SetInputData_37(vtkTable id0,String id1,String id2);
  public void SetInputData(vtkTable id0,String id1,String id2)
    { SetInputData_37(id0,id1,id2); }

  private native void SetInputData_38(vtkTable id0,int id1,int id2);
  public void SetInputData(vtkTable id0,int id1,int id2)
    { SetInputData_38(id0,id1,id2); }

  private native long GetInput_39();
  public vtkTable GetInput() {
    long temp = GetInput_39();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetInputArray_40(int id0,String id1);
  public void SetInputArray(int id0,String id1)
    { SetInputArray_40(id0,id1); }

  private native void SetSelectable_41(boolean id0);
  public void SetSelectable(boolean id0)
    { SetSelectable_41(id0); }

  private native boolean GetSelectable_42();
  public boolean GetSelectable()
    { return GetSelectable_42(); }

  private native void SelectableOn_43();
  public void SelectableOn()
    { SelectableOn_43(); }

  private native void SelectableOff_44();
  public void SelectableOff()
    { SelectableOff_44(); }

  private native void SetSelection_45(vtkIdTypeArray id0);
  public void SetSelection(vtkIdTypeArray id0)
    { SetSelection_45(id0); }

  private native long GetSelection_46();
  public vtkIdTypeArray GetSelection() {
    long temp = GetSelection_46();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetXAxis_47();
  public vtkAxis GetXAxis() {
    long temp = GetXAxis_47();

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetXAxis_48(vtkAxis id0);
  public void SetXAxis(vtkAxis id0)
    { SetXAxis_48(id0); }

  private native long GetYAxis_49();
  public vtkAxis GetYAxis() {
    long temp = GetYAxis_49();

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetYAxis_50(vtkAxis id0);
  public void SetYAxis(vtkAxis id0)
    { SetYAxis_50(id0); }

  private native void GetBounds_51(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_51(id0); }

  private native void GetUnscaledInputBounds_52(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_52(id0); }

  private native void UpdateCache_53();
  public void UpdateCache()
    { UpdateCache_53(); }

  public vtkPlot() { super(); }

  public vtkPlot(long id) { super(id); }

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkPlot.java <==
// java wrapper for vtkPlot object
//

package vtk;
import vtk.*;

public class vtkPlot extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLegendVisibility_2(boolean id0);
  public void SetLegendVisibility(boolean id0)
    { SetLegendVisibility_2(id0); }

  private native boolean GetLegendVisibility_3();
  public boolean GetLegendVisibility()
    { return GetLegendVisibility_3(); }

  private native void LegendVisibilityOn_4();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_4(); }

  private native void LegendVisibilityOff_5();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_5(); }

  private native void SetTooltipLabelFormat_6(String id0);
  public void SetTooltipLabelFormat(String id0)
    { SetTooltipLabelFormat_6(id0); }

  private native String GetTooltipLabelFormat_7();
  public String GetTooltipLabelFormat()
    { return GetTooltipLabelFormat_7(); }

  private native void SetTooltipNotation_8(int id0);
  public void SetTooltipNotation(int id0)
    { SetTooltipNotation_8(id0); }

  private native int GetTooltipNotation_9();
  public int GetTooltipNotation()
    { return GetTooltipNotation_9(); }

  private native void SetTooltipPrecision_10(int id0);
  public void SetTooltipPrecision(int id0)
    { SetTooltipPrecision_10(id0); }

  private native int GetTooltipPrecision_11();
  public int GetTooltipPrecision()
    { return GetTooltipPrecision_11(); }

  private native void SetColor_12(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_12(id0,id1,id2,id3); }

  private native void SetColor_13(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_13(id0,id1,id2); }

  private native void GetColor_14(double id0[]);
  public void GetColor(double id0[])
    { GetColor_14(id0); }

  private native void SetWidth_15(double id0);
  public void SetWidth(double id0)
    { SetWidth_15(id0); }

  private native double GetWidth_16();
  public double GetWidth()
    { return GetWidth_16(); }

  private native void SetPen_17(vtkPen id0);
  public void SetPen(vtkPen id0)
    { SetPen_17(id0); }

  private native long GetPen_18();
  public vtkPen GetPen() {
    long temp = GetPen_18();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBrush_19(vtkBrush id0);
  public void SetBrush(vtkBrush id0)
    { SetBrush_19(id0); }

  private native long GetBrush_20();
  public vtkBrush GetBrush() {
    long temp = GetBrush_20();

    if (temp == 0) return null;
    return (vtkBrush)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionPen_21(vtkPen id0);
  public void SetSelectionPen(vtkPen id0)
    { SetSelectionPen_21(id0); }

  private native long GetSelectionPen_22();
  public vtkPen GetSelectionPen() {
    long temp = GetSelectionPen_22();

    if (temp == 0) return null;
    return (vtkPen)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionBrush_23(vtkBrush id0);
  public void SetSelectionBrush(vtkBrush id0)
    { SetSelectionBrush_23(id0); }

  private native long GetSelectionBrush_24();
  public vtkBrush GetSelectionBrush() {
    long temp = GetSelectionBrush_24();

    if (temp == 0) return null;
    return (vtkBrush)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabel_25(String id0);
  public void SetLabel(String id0)
    { SetLabel_25(id0); }

  private native String GetLabel_26();
  public String GetLabel()
    { return GetLabel_26(); }

  private native void SetLabels_27(vtkStringArray id0);
  public void SetLabels(vtkStringArray id0)
    { SetLabels_27(id0); }

  private native long GetLabels_28();
  public vtkStringArray GetLabels() {
    long temp = GetLabels_28();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfLabels_29();
  public int GetNumberOfLabels()
    { return GetNumberOfLabels_29(); }

  private native String GetLabel_30(int id0);
  public String GetLabel(int id0)
    { return GetLabel_30(id0); }

  private native void SetIndexedLabels_31(vtkStringArray id0);
  public void SetIndexedLabels(vtkStringArray id0)
    { SetIndexedLabels_31(id0); }

  private native long GetIndexedLabels_32();
  public vtkStringArray GetIndexedLabels() {
    long temp = GetIndexedLabels_32();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_33();
  public vtkContextMapper2D GetData() {
    long temp = GetData_33();

    if (temp == 0) return null;
    return (vtkContextMapper2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean GetUseIndexForXSeries_34();
  public boolean GetUseIndexForXSeries()
    { return GetUseIndexForXSeries_34(); }

  private native void SetUseIndexForXSeries_35(boolean id0);
  public void SetUseIndexForXSeries(boolean id0)
    { SetUseIndexForXSeries_35(id0); }

  private native void SetInputData_36(vtkTable id0);
  public void SetInputData(vtkTable id0)
    { SetInputData_36(id0); }

  private native void SetInputData_37(vtkTable id0,String id1,String id2);
  public void SetInputData(vtkTable id0,String id1,String id2)
    { SetInputData_37(id0,id1,id2); }

  private native void SetInputData_38(vtkTable id0,int id1,int id2);
  public void SetInputData(vtkTable id0,int id1,int id2)
    { SetInputData_38(id0,id1,id2); }

  private native long GetInput_39();
  public vtkTable GetInput() {
    long temp = GetInput_39();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputArray_40(int id0,String id1);
  public void SetInputArray(int id0,String id1)
    { SetInputArray_40(id0,id1); }

  private native void SetSelectable_41(boolean id0);
  public void SetSelectable(boolean id0)
    { SetSelectable_41(id0); }

  private native boolean GetSelectable_42();
  public boolean GetSelectable()
    { return GetSelectable_42(); }

  private native void SelectableOn_43();
  public void SelectableOn()
    { SelectableOn_43(); }

  private native void SelectableOff_44();
  public void SelectableOff()
    { SelectableOff_44(); }

  private native void SetSelection_45(vtkIdTypeArray id0);
  public void SetSelection(vtkIdTypeArray id0)
    { SetSelection_45(id0); }

  private native long GetSelection_46();
  public vtkIdTypeArray GetSelection() {
    long temp = GetSelection_46();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetXAxis_47();
  public vtkAxis GetXAxis() {
    long temp = GetXAxis_47();

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetXAxis_48(vtkAxis id0);
  public void SetXAxis(vtkAxis id0)
    { SetXAxis_48(id0); }

  private native long GetYAxis_49();
  public vtkAxis GetYAxis() {
    long temp = GetYAxis_49();

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetYAxis_50(vtkAxis id0);
  public void SetYAxis(vtkAxis id0)
    { SetYAxis_50(id0); }

  private native void GetBounds_51(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_51(id0); }

  private native void GetUnscaledInputBounds_52(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_52(id0); }

  private native void UpdateCache_53();
  public void UpdateCache()
    { UpdateCache_53(); }

  public vtkPlot() { super(); }

  public vtkPlot(long id) { super(id); }

}
